@@ -1061,9 +1061,9 @@ class SendEmailRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param FromEmailAddress: 发信邮件地址。请填写发件人邮箱地址，例如：noreply@mail.qcloud.com。如需填写发件人说明，请按照 
-发信人 <邮件地址> 的方式填写，例如：
-腾讯云团队 <noreply@mail.qcloud.com>
+        :param FromEmailAddress: 发信邮件地址。请填写发件人邮箱地址，例如：noreply@mail.qcloud.com
+如需填写发件人说明，请按照如下方式： 
+别名 <邮箱地址>
         :type FromEmailAddress: str
         :param Destination: 收信人邮箱地址，最多支持群发50人。注意：邮件内容会显示所有收件人地址，非群发邮件请多次调用API发送。
         :type Destination: list of str
@@ -1077,6 +1077,8 @@ class SendEmailRequest(AbstractModel):
         :type Simple: :class:`tencentcloud.ses.v20201002.models.Simple`
         :param Attachments: 需要发送附件时，填写附件相关参数。
         :type Attachments: list of Attachment
+        :param Unsubscribe: 是否加入退订链接
+        :type Unsubscribe: str
         """
         self.FromEmailAddress = None
         self.Destination = None
@@ -1085,6 +1087,7 @@ class SendEmailRequest(AbstractModel):
         self.Template = None
         self.Simple = None
         self.Attachments = None
+        self.Unsubscribe = None
 
 
     def _deserialize(self, params):
@@ -1104,6 +1107,7 @@ class SendEmailRequest(AbstractModel):
                 obj = Attachment()
                 obj._deserialize(item)
                 self.Attachments.append(obj)
+        self.Unsubscribe = params.get("Unsubscribe")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
